package com.gestalt.jbi.component.manager;

import java.util.logging.Level;

import javax.jbi.messaging.DeliveryChannel;
import javax.jbi.messaging.MessagingException;
import javax.jbi.messaging.MessageExchange.Role;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.wsdl.Definition;
import javax.xml.namespace.QName;

import org.w3c.dom.Document;

import com.gestalt.jbi.component.handler.AbstractMessageExchangeHandler;
import com.gestalt.jbi.component.lifecycle.AbstractComponentLifeCycle;

public abstract class PooledEndpoint extends Endpoint {
	
    public PooledEndpoint(QName serviceName, QName interfaceName, String endpointName, Role role, Document serviceDescription, Definition wsdlDefinition, ServiceUnit serviceUnit) {
		super(serviceName, interfaceName, endpointName, role, serviceDescription,
				wsdlDefinition, serviceUnit);
	}

	public void activate() throws Exception {
        log.log(Level.INFO, "Activating endpoint");
        if (Role.PROVIDER.equals(role)) {
            activatedEndpoint = ((AbstractComponentLifeCycle) serviceUnit.getComponent().getLifeCycle()).getComponentContext().activateEndpoint(serviceName, endpointName);
        } 
    }

    public void deactivate() throws Exception {
        log.log(Level.INFO, "Deactivating endpoint");
        processor = null;
        if (Role.PROVIDER.equals(role)) {
            ServiceEndpoint tmp = activatedEndpoint;
            activatedEndpoint = null;
            ((AbstractComponentLifeCycle) serviceUnit.getComponent().getLifeCycle()).getComponentContext().deactivateEndpoint(tmp);
        }
    }
    
    public AbstractMessageExchangeHandler getProcessor() {
        if (Role.PROVIDER.equals(role)) {
        	return createProviderExchangeHandler();
        }
		try {
			AbstractMessageExchangeHandler processor = createConsumerExchangeHandler();
			log.log(Level.INFO,"Setting Delivery Channel on the Consumer Exchange Handler");
			DeliveryChannel tempChannel = ((AbstractComponentLifeCycle) serviceUnit.getComponent().getLifeCycle()).getComponentContext().getDeliveryChannel();
			if (tempChannel == null) {
				log.log(Level.WARNING,"DeliveryChannel is NULL");
			}
			processor.setDeliveryChannel(tempChannel);
			return processor;
		} catch (MessagingException e) {
			log.log(Level.WARNING, e.getMessage());
		}
		return null;
	}
	
}
