/**
 *   common-jbi-runtime.jar - Set of classes used in building JBI Components
 *
 *   Copyright (C) 2007 Gestalt, LLC. All Rights Reserved.
 *   http://www.gestalt-llc.com/
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License version 2.1 as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 */

package com.gestalt.jbi.component.manager.deployment;

import com.gestalt.jbi.component.AbstractComponent;
import com.gestalt.jbi.component.manager.ServiceUnit;

import javax.jbi.management.DeploymentException;
import java.util.logging.Logger;

public abstract class AbstractDeployer {
	protected static final Logger log =
            Logger.getLogger(AbstractDeployer.class.getName());
	
	protected AbstractComponent component;
	
	public AbstractDeployer(AbstractComponent component) {
		this.component = component;
	}
	
	public void shutdown(ServiceUnit serviceUnit) throws DeploymentException {
		log.fine("Shutting down service unit");
		try {
			serviceUnit.shutdown();
		} catch (Exception e) {	
			log.throwing(getClass().getName(), "shutdown", e);
			throw new DeploymentException("Failed to shutdown service unit - "
                    + serviceUnit.getServiceUnitName() + " : "
                    + e.getMessage(), e);
		}
	}
	
	public abstract boolean canDeploy(String serviceUnitRootPath);
	
	public abstract ServiceUnit deploy(String serviceUnitName,
            String serviceUnitRootPath) throws DeploymentException;
	
}
